@@ -1,6 +1,11 @@
 import os
 import sys
 import cv2
+__dir__ = os.path.dirname(__file__)
+
+# import paddle
+
+sys.path.append(os.path.join(__dir__, ''))
 
 from PaddleOCR.paddleocr import PaddleOCR
 import numpy as np
@@ -158,5 +163,4 @@ class OcrLicense:
                     break
 
         return output
-
 OcrLicense()
\ No newline at end of file
